// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KONQ_VERSION_H
#define KONQ_VERSION_H

#define KONQ_VERSION_STRING "5.97.0"
#define KONQ_VERSION_MAJOR 5
#define KONQ_VERSION_MINOR 97
#define KONQ_VERSION_PATCH 0
#define KONQ_VERSION ((5<<16)|(97<<8)|(0))

#endif
