
#ifndef LIBKONQSETTINGS_EXPORT_H
#define LIBKONQSETTINGS_EXPORT_H

#ifdef LIBKONQSETTINGS_STATIC_DEFINE
#  define LIBKONQSETTINGS_EXPORT
#  define LIBKONQSETTINGS_NO_EXPORT
#else
#  ifndef LIBKONQSETTINGS_EXPORT
#    ifdef KF6KonqSettings_EXPORTS
        /* We are building this library */
#      define LIBKONQSETTINGS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define LIBKONQSETTINGS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef LIBKONQSETTINGS_NO_EXPORT
#    define LIBKONQSETTINGS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef LIBKONQSETTINGS_DEPRECATED
#  define LIBKONQSETTINGS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef LIBKONQSETTINGS_DEPRECATED_EXPORT
#  define LIBKONQSETTINGS_DEPRECATED_EXPORT LIBKONQSETTINGS_EXPORT LIBKONQSETTINGS_DEPRECATED
#endif

#ifndef LIBKONQSETTINGS_DEPRECATED_NO_EXPORT
#  define LIBKONQSETTINGS_DEPRECATED_NO_EXPORT LIBKONQSETTINGS_NO_EXPORT LIBKONQSETTINGS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LIBKONQSETTINGS_NO_DEPRECATED
#    define LIBKONQSETTINGS_NO_DEPRECATED
#  endif
#endif

#endif /* LIBKONQSETTINGS_EXPORT_H */
