<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="khtmlsettingsplugin" version="4" translationDomain="khtmlsettingsplugin">
<MenuBar>
 <Menu name="tools"><text>&amp;Tools</text>
  <Action name="action menu"/>
 </Menu>
</MenuBar>
<ToolBar name="extraToolBar"><text>Extra Toolbar</text>
  <Action name="action menu"/>
</ToolBar>
</gui>
