// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KONQSETTINGS_VERSION_H
#define KONQSETTINGS_VERSION_H

#define KONQSETTINGS_VERSION_STRING "5.97.0"
#define KONQSETTINGS_VERSION_MAJOR 5
#define KONQSETTINGS_VERSION_MINOR 97
#define KONQSETTINGS_VERSION_PATCH 0
#define KONQSETTINGS_VERSION ((5<<16)|(97<<8)|(0))

#endif
